==> ansible-11.5.0-2.0-any.pkg.tar.zst: usr/lib/python3.13/site-packages/ansible_collections/cisco/dnac/plugins/modules/network_device_global_polling_interval_info.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-
# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
DOCUMENTATION = r"""
---
module: network_device_global_polling_interval_info
short_description: Information module for Network Device Global Polling Interval Info
description:
  - This module represents an alias of the module network_device_global_polling_interval_v1_info
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
requirements:
  - dnacentersdk >= 2.4.9
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Devices GetPollingIntervalForAllDevicesV1
    description: Complete reference of the GetPollingIntervalForAllDevicesV1 API.
    link:
      https://developer.cisco.com/docs/dna-center/#!get-polling-interval-for-all-devices
notes:
  - SDK Method used are devices.Devices.get_polling_interval_for_all_devices_v1,
  - Paths used are get /dna/intent/api/v1/network-device/collection-schedule/global,
  - It should be noted that this module is an alias of network_device_global_polling_interval_v1_info
"""
EXAMPLES = r"""
- name: Get all Network Device Global Polling Interval Info
  cisco.dnac.network_device_global_polling_interval_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": 0,
      "version": "string"
    }
"""

==> ansible-12.0.0-2-any.pkg.tar.zst: usr/lib/python3.12/site-packages/ansible_collections/cisco/dnac/plugins/modules/network_device_global_polling_interval_info.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_device_global_polling_interval_info
short_description: Information module for Network Device
  Global Polling Interval
description:
  - Get all Network Device Global Polling Interval.
  - Returns polling interval of all devices.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Devices
      GetPollingIntervalForAllDevices
    description: Complete reference of the GetPollingIntervalForAllDevices
      API.
    link: https://developer.cisco.com/docs/dna-center/#!get-polling-interval-for-all-devices
notes:
  - SDK Method used are
    devices.Devices.get_polling_interval_for_all_devices,
  - Paths used are
    get /dna/intent/api/v1/network-device/collection-schedule/global,
"""

EXAMPLES = r"""
---
- name: Get all Network Device Global Polling Interval
  cisco.dnac.network_device_global_polling_interval_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": 0,
      "version": "string"
    }
"""
